@@ -1,5 +1,5 @@
 /* mv -- move or rename files
-   Copyright (C) 1986-2015 Free Software Foundation, Inc.
+   Copyright (C) 1986-2016 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,6 @@
 #include "cp-hash.h"
 #include "error.h"
 #include "filenamecat.h"
-#include "quote.h"
 #include "remove.h"
 #include "root-dev-ino.h"
 #include "priv-set.h"
@@ -96,7 +95,7 @@ rm_option_init (struct rm_options *x)
     x->root_dev_ino = get_root_dev_ino (&dev_ino_buf);
     if (x->root_dev_ino == NULL)
       error (EXIT_FAILURE, errno, _("failed to get attributes of %s"),
-             quote ("/"));
+             quoteaf ("/"));
   }
 }
 
@@ -153,7 +152,7 @@ target_directory_operand (char const *file)
   int err = (stat (file, &st) == 0 ? 0 : errno);
   bool is_a_dir = !err && S_ISDIR (st.st_mode);
   if (err && err != ENOENT)
-    error (EXIT_FAILURE, err, _("failed to access %s"), quote (file));
+    error (EXIT_FAILURE, err, _("failed to access %s"), quoteaf (file));
   return is_a_dir;
 }
 
@@ -403,10 +402,10 @@ main (int argc, char **argv)
               struct stat st;
               if (stat (optarg, &st) != 0)
                 error (EXIT_FAILURE, errno, _("failed to access %s"),
-                       quote (optarg));
+                       quoteaf (optarg));
               if (! S_ISDIR (st.st_mode))
                 error (EXIT_FAILURE, 0, _("target %s is not a directory"),
-                       quote (optarg));
+                       quoteaf (optarg));
             }
           target_directory = optarg;
           break;
@@ -448,7 +447,7 @@ main (int argc, char **argv)
         error (0, 0, _("missing file operand"));
       else
         error (0, 0, _("missing destination file operand after %s"),
-               quote (file[0]));
+               quoteaf (file[0]));
       usage (EXIT_FAILURE);
     }
 
@@ -460,7 +459,7 @@ main (int argc, char **argv)
                  "and --no-target-directory (-T)"));
       if (2 < n_files)
         {
-          error (0, 0, _("extra operand %s"), quote (file[2]));
+          error (0, 0, _("extra operand %s"), quoteaf (file[2]));
           usage (EXIT_FAILURE);
         }
     }
@@ -481,7 +480,7 @@ main (int argc, char **argv)
         target_directory = file[--n_files];
       else if (2 < n_files)
         error (EXIT_FAILURE, 0, _("target %s is not a directory"),
-               quote (file[n_files - 1]));
+               quoteaf (file[n_files - 1]));
     }
 
   if (make_backups && x.interactive == I_ALWAYS_NO)
